svn commit: r18635 - trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: mvw
Date: 2010-08-12 00:49:43-0700
New Revision: 18635

Modified:
   trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java

Log:
Changed the name of a parameter to clarify its meaning.
Improved comments.

Modified: trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java?view=diff&pathrev=18635&r1=18634&r2=18635
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/notation/providers/uml/ModelElementNameNotationUml.java	2010-08-12 00:49:43-0700
@@ -1,6 +1,6 @@
 /* $Id$
  *****************************************************************************
- * Copyright (c) 2009 Contributors - see below
+ * Copyright (c) 2009-2010 Contributors - see below
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -49,22 +49,22 @@
 import org.argouml.notation.providers.ModelElementNameNotation;
 
 /**
- * Handles the notation of the name of a modelelement in UML,
- * ie a string on the format:<pre>
+ * Handles the notation of the name of a modelElement in UML,
+ * i.e. a string on the format:<pre>
  *     [ &lt;&lt; stereotype &gt;&gt;] [+|-|#] [name]
  * </pre>
  *
- * @author [email protected]
+ * @author mvw
  */
 public class ModelElementNameNotationUml extends ModelElementNameNotation {
 
     /**
      * The constructor.
      *
      * @param name the uml object
      */
-    public ModelElementNameNotationUml(Object name) {
-        super(name);
+    public ModelElementNameNotationUml(Object modelElement) {
+        super(modelElement);
     }
 
     /*

------------------------------------------------------
@@ -49,22 +49,22 @@
      * The constructor.
      *
-     * @param name the uml object
+     * @param modelElement the UML object
      */
http://argouml.tigris.org/ds/viewMessage.do?dsForumId=5905&dsMessageId=2645921

To unsubscribe from this discussion, e-mail: [[email protected]].
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.